#
# spec file for package nanomsg
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 6
Name:           nanomsg
Version:        1.2
Release:        1.4
Summary:        Socket library providing several common communication patterns
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://nanomsg.org/
Source:         https://github.com/nanomsg/nanomsg/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         nanomsg-fix-rpath-issue.patch
BuildRequires:  cmake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
nanomsg is a C socket library providing several common communication
patterns.

%package -n libnanomsg%{sover}
Summary:        Shared library for nanomsg
Group:          System/Libraries

%description -n libnanomsg%{sover}
nanomsg is a C socket library providing several common communication
patterns.

%package devel
Summary:        Header files for nanomsg
Group:          Development/Libraries/C and C++
Requires:       libnanomsg%{sover} = %{version}

%description devel
Development and header files for nanomsg.

%prep
%setup -q
%patch0 -p1

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%post   -n libnanomsg%{sover} -p /sbin/ldconfig
%postun -n libnanomsg%{sover} -p /sbin/ldconfig

%files -n libnanomsg%{sover}
%license COPYING
%doc RELEASING AUTHORS README.md
%{_libdir}/libnanomsg.so.*

%files devel
%{_includedir}/nanomsg
%{_libdir}/libnanomsg.so
%{_bindir}/nanocat
%{_libdir}/pkgconfig/nanomsg.pc
%dir %{_libdir}/cmake/nanomsg-1.1.5
%{_libdir}/cmake/nanomsg-1.1.5/nanomsg-config*.cmake
%{_libdir}/cmake/nanomsg-1.1.5/nanomsg-target*.cmake

%changelog
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2:
  * IPv6 support and fixes a couple of bugs.
* Mon Mar 30 2020 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * nanomsg-fix-rpath-issue.patch
* Sun Mar 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.5
  * This release is a minor bug fix release, and includes some
    improvements to the CMake logic that should make incorporating
    nanomsg into larger projects easier.
  * Removed patch:
  - strict.diff (fixed by upstream) GH#990
* Fri Jun  8 2018 mardnh@gmx.de
- Update to version 1.1.4
  * This release is primarily a bug-fix release for Windows
    platforms, but it also adds support for building on Android.
  * The main change in this release is a fix for the IPC transport
    on Windows, which was subject to crashing if the remote peer
    breaks messages into smaller pieces.
    As some other SP implementations do this to avoid data copies,
    this fix is very important.
  * A fix for leaking handles on Windows is included.
  * Support for compilation on Android using the NDK and the
    bundled cmake and toolchain file from Android is now present.
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 1.1.3
  * CMake exported target, easing inclusion in larger projects
    (see demos/CMakeLists.txt for an example)
  * Windows no longer uses a single fixed TCP port for eventfd
    (this should improve reliability)
  * Fix for an assertion failure in efd_unsignal
  * The ABI version is separate from the library version now.
  * Fixed a crash when calling nn_term without first opening a
    socket.
  * Fix for building Windows tests on case-sensitive file systems.
  * CI/CD improvements: switch to CircleCI, and use CodeCov for
    coverage analysis.
* Tue Nov  7 2017 mardnh@gmx.de
- update to version 1.1.2
  This is a bug fix release for 1.1.0.
  Two main issues are resolved:
  * nanomsg no longer wakes up every 100 msec even when no I/O is
    pending
  * Some users noticed that nanomsg was performing wakeups
    regardless of whether I/O was available or not.
    This had a detrimental effect on power usage.
  * In some circumstances an outstanding accept() operation that
    got aborted (for example due to the socket closing) could wind
    up crashing the application.
    This was a race, and it is closed now.
* Fri Oct 20 2017 mardnh@gmx.de
- update to version 1.1.0
  * This release is primarily a bug fix release for nanomsg, and
    rolls up a number of stability improvements, particularly for
    the inproc transport.
  * A port to support Windows Subsystem for Linux is provided as well.
  * There are no changes to the ABI.
* Fri Apr 28 2017 jengelh@inai.de
- Rename archive to have correct extension.
- Add strict.diff
* Fri Apr 28 2017 jengelh@inai.de
- Update descriptions
* Thu Apr 13 2017 mardnh@gmx.de
- update to version 1.0.0 (tagged release)
- specfile cleanup
* Mon Mar 28 2016 mardnh@gmx.de
- update to version 0.8+git.1454566536.8f873b4
* Tue May 27 2014 dmacvicar@suse.de
- initial package for 0.3+git.1400232496.c00be36
